/**
 * \defgroup g_list 2. libfat: Operazioni Supportate dal Filesystem SFAT
 *
 * Questa sezione descrive le operazioni che devopno essere implementate 
 * nella libreria libfat.
 * <HR>
 * <br>
 * <H3>Formattazione di un Filesystem</H3>
 *
 * La funzione per la formattazione del filesystem ha il seguente prototipo:
 * <center>
 * \verbatim
   int fat_format (FILE *fs, int block_size, unsigned int num_block);
  \endverbatim
 * </center>
 *
 * @copydoc fat_format
 *
 * La funzione e' dichiarata nel file format.h mentre la test suite per questa
 * funzione e' specificata nel file format_suite.c
 *
 * \warning La test suite per la funzione \c fat_format puo' essere eseguito solo se 
 * e' stata implementata anche la funzione mount_fat.
 *
 * <HR>
 * <br>
 * <H3>Mounting di un Filesysem SFAT</H3>
 * 
 * La funzione per il caricamento di un filesystem SFAT ha il seguente prototipo:
 * <center>
 * \verbatim
   int 	mount_fat (FILE *fs, struct fat_ctrl *f_ctrl)
  \endverbatim
 * </center>
 *
 * @copydoc mount_fat
 *
 * La funzione e' dichiarata nel file load_fat.h mentre la test suite per questa
 * funzione e' specificata nel file format_suite.c
 * <HR>
 *
 * <br>
 * <H3>Creazione di una Directory</H3>
 *
 * La funzione per la creazione di una direcotry  ha il seguente prototipo:
 * <center>
 * \verbatim
   int 	fat_mkdir (FILE *fs, struct fat_ctrl *f_ctrl, char *path);
  \endverbatim
 * </center>
 *
 * @copydoc fat_mkdir
 *
 * La funzione e' dichiarata nel file make_dir.h mentre la test suite per questa
 * funzione e' specificata nel file mkdir_suite.c
 *
 * \warning La test suite per la funzione fat_mkdir puo' essere eseguito solo se 
 * e' stata implementata anche la funzione fat_ls .
 *
 * <HR>
 *
 * <br>
 * <H3>Listing di una Directory</H3>
 *
 * La funzione per il listing di una direcotry  ha il seguente prototipo:
 * <center>
 * \verbatim
   int fat_ls(FILE *fs, struct fat_ctrl *f_ctrl, char *path, char **list)
  \endverbatim
 * </center>
 *
 * @copydoc fat_ls
 *
 * La funzione e' dichiarata nel file list.h mentre la test suite per questa
 * funzione e' specificata nel file mkdir_suite.c
 *
 * \warning La test suite per la funzione fat_ls puo' essere eseguito solo se 
 * e' stata implementata anche la funzione fat_mkdir .
 *
 * <HR>
 *
 * <br>
 * <H3>Creazione di un File</H3>
 * La funzione per la creazione di un file  ha il seguente prototipo:
 * <center>
 * \verbatim
   int fat_open (FILE *fs, struct fat_ctrl *f_ctrl, char *path);
  \endverbatim
 * </center>
 *
 * @copydoc fat_open
 *
 * La funzione e' dichiarata nel file open_fat.h mentre la test suite per questa
 * funzione e' specificata nel file open_suite.c .
 *
 * <HR>
 *
 * <br>
 * <H3>Scrittura di un File</H3>
 *
 * La funzione per la scrittura all'interno di un file ha il seguente prototipo:
 * <center>
 * \verbatim
   int fat_write(FILE *fs, struct fat_ctrl *f_ctrl, char *path, char* data, int data_len);
  \endverbatim
 * </center>
 *
 * @copydoc fat_write
 *
 * La funzione e' dichiarata nel file write_fat.h mentre la test suite per questa
 * funzione e' specificata nel file rw_suite.c .
 *
 * \warning La test suite per la funzione write_fat.c puo' essere eseguito solo se 
 * e' stata implementata anche la funzione read_fat.c .
 *
 * <HR>
 *
 * <br>
 * <H3>Lettura di un File</H3>
 *
 * La funzione per la lettura di un file ha il seguente prototipo:
 * <center>
 * \verbatim
   int fat_read(FILE *fs, struct fat_ctrl *f_ctrl, char *path, int start, int data_len, char *data);
  \endverbatim
 * </center>
 *
 * @copydoc fat_read
 *
 * La funzione e' dichiarata nel file read_fat.h mentre la test suite per questa
 * funzione e' specificata nel file rw_suite.c .
 *
 * \warning La test suite per la funzione read_fat.c puo' essere eseguito solo se 
 * e' stata implementata anche la funzione write_fat.c  .
 * <HR>
 *
 * <br>
 * \warning
 *
 * Con il programma definito nel file all_tests.c e' possibile eseguire con un
 * singolo comando tutte le test suites definite per il progetto SFAT.
 */
