/**
 * \file
 * \brief Operazione di \e directory \e listing.
 * \author lcs07
 * 
 */

#include "fat.h"
/**
 * Questa funzione effettua l'operazione di \e listing di una directory.  In
 * particolare ha il compito di generare la lista dei file e subdirectory
 * contenute all'interno di una directory. La lista e' rappresentata da una
 * stringa in cui i nomi dei file sono separati dal carattere \c '\\t'.  La
 * lista non viene esplicitamente ordinata, ma i nomi appaiono nell'ordine in
 * cui sono letti dalla directory table delle directory su cui si sta
 * effettuando l'operazione di listing.
 *
 * \param fs il FILE pointer che consente di acceddere al
 *           file dove il filesystem e' memorizzato.
 * \param f_ctrl puntatore alla struttura che mantiene tutte 
 *               le informazioni di controllo del filesystem.
 * \param path il path assoluto della directory di cui dobbiamo
 *             effettuare il listing.
 * \param list [OUT] indirizzo di un puntatore. Dopo l'elaborazione conterra' 
 *             riferimento a una stringa contenente tutti
 *             i nomi dei files e delle subdirectory contenuti
 *             nella directory definita da \a path. I nomi 
 *             sono separati dal carattere \\t (tab). 
 * \returns 
 *         - EBDP (Error Bad Directory Path) se il path specificato
 *           non e' assoluto, ossia non inizia con il carattere '/'
 *         - ERFCD (Error Reading Fat Control Data) se si verifica 
 *           un errore leggendo le strutture di controllo del
 *           filesystem Fat.
 *         - ENSFD (Error Not Such File or Directory) se un elemento del
 *           pah non siste o non e' una directory.
 *         - ERDB (Error Reading Block Data) se si verifica un errore
 *            di lettura di un blocco.
 *         - 0 in caso di sucesso.
 */
int fat_ls(FILE *fs, struct fat_ctrl *f_ctrl, char *path, char** list);
