/**
 *   \file
 *   \brief Operazione di creazione directory
 *   \author lcs07
 */
#include "fat.h"
/**
 * Questa funzione ha il compito di creare una subdirectory \e SUBDIR
 * all'interno di una directory \e DIR. Il pathname con cui si effettua
 * la creazione della directory e' formato da \e DIR/SUBDIR. Ad esempio
 * il pathname \c /this/is/a/path/name/example e' formato dal pathname
 * assoluto della directory \e DIR= \c /this/is/a/path/name/ in cui si
 * vuole creare una nuova subdirectory, ed il nome \e SUBDIR= \c example
 * della subdirectory che si vuole creare. Ogni singola componete del
 * pathname \e DIR (e.g. \c this \c is \c a ecc.) viene riferito con il
 * termine \e path \e element.  
 * In particolare questa funzione ha il compito di:
 *
 * - Controllare che il pathname \e DIR/SUBDIR sia valido, ossia:
 *   -# \e DIR sia un path assoluto.
 *   -# Ogni path element in \e DIR non ecceda la lunghezza consentita dal
 *      filesystem FAT (MAX_LEN_NAME).
 * - Navigare all'interno del filesystem seguendo i singoli path element. 
 *   Se uno di tali elementi non esiste oppure non e' una directory 
 *   l'operazione deve terminare con fallimento.
 * - Controllare che il nome della nuova subdirectory \e SUBD non sia
 *   gia' presente all'interno della directory \e DIR. In tal caso 
 *   l'operazione deve terminare con fallimento.
 * - Allocare un nuovo blocco per contenere la directory table per \e SUBD
 *   ed inserire le entries \e "." e \e ".."
 * - Preparare la nuova entry da inserire all'interno della directory
 *   table di \e DIR.
 * - Effettuare l'inserimento della entry creata al passo precedente 
 *   all'interno della directory table di \e DIR.
 *
 *
 * \param fs il FILE pointer che consente di accedere al
 *           file dove il filesystem e' memorizzato.
 * \param f_ctrl puntatore alla struttura che mantiene tutte 
 *               le informazioni di controllo del filesystem.
 * \param path il path assoluto in cui creare la nuova directory.
 *             L'ultimo elemento del path e' il nome della nuova
 *             directory. Ad esempio se <em>path = /home/pippo </em>allora
 *             la directory che deve essere creata ha nome \e pippo e deve
 *             essere creata come subdirectory di \e /home.
 * \returns 
 *         - EBDP (Error Bad Directory Path) se il path specificato
 *           non e' assoluto, ossia non inizia con il carattere '/'
 *         - ENTL (Error Name Too Long) uno degli elementi del pathname
 *           supera la lunghezza consentita (MAX_LEN_NAME).
 *         - ENSFD (Error Not Such File or Directory) se un elemento del
 *           pah non siste o non e' una directory.
 *         - ENMSD (Error No More Space on Device) se non ci 
 *           sono piu' blocchi disponibili e quindi ci troviamo
 *           in una condizione di Filesystem Full.
 *         - ERFCD (Error Reading Fat Control Data) se si verifica 
 *           un errore leggendo le strutture di controllo del
 *           filesystem Fat.
 *         - EWFCD (Error Writing Fat Control Data) se si verifica 
 *           un errore durante la scrittura delle strutture di 
 *           controllo del filesystem Fat.
 *         - 0 (zero) in caso di successo.
 */
int fat_mkdir (FILE *fs, struct fat_ctrl *f_ctrl, char *path);
