/**
 * \file open_fat.h
 * \brief Creazione di un file.
 * \author lcs07
 */
#include "fat.h"
/**
 * Questa funzione ha il compito di creare un nuovo file all'interno del
 * filesystem SFAT. Il nome del file \e F viene espresso tramite un pathname
 * assoluto come ad esempio \c /dir/name/fileName in cui il nome del file \e F
 * e' specificato dall'ultimo elemento del pathname (\c fileNmae) e la
 * directrory \e D in cui deve essere creato il file e' specificata dalla
 * prima parte del pathname (\c /dir/name ). In particolare questa funzione
 * deve:
 *
 * - Separare il nome del file dal path che specifica la directory \e D dove il
 *   file deve essere generato.
 * - Controllare che la directory \e D esista, ossia che il pathname sia corretto.
 * - Controllare che il file \e F non sia gia' esistente.
 * - Determinare la directory table di \e D. 
 * - Determinare in \e D una entry libera in cui inserire le informazioni
 *   relative al file \e F che deve essere generato. Puo' risultare necessario
 *   aggiungere un nuovo blocco alla directory table \e D.
 * - Selezionare un blocco libero \e B che conterra' il primo byte del file \e F.
 * - Preparare i dati da inserire nella entry che includono:
 *   - \c used valorizzata a DIR_ENTRY_BUSY.
 *   - \c name valorizzato al nome del file \e F.
 *   - \c attr valorizzato a FILE_ENTRY.
 *   - \c index valorizzato all'indice del blocco \e B che contiene
 *     il primo byte del file.
 *   - \c len valorizzato a 0 (alla creazione il file e' vuoto).
 *
 * @param fs il FILE pointer che consente di acceddre al
 *           file dove il filesystem e' memorizzato.
 * @param f_ctrl puntatore alla struttura che mantiene tutte 
 *               le informazioni di controllo del filesystem.
 * @param path la stringa che contiene il path assoluto del
 *              file che deve essere creato.
 * @returns
 *         - EBDP (Error Bad Directory Path) se il path specificato
 *           non e' assoluto, ossia non inizia con il carattere '/'
 *         - ENTL (Error Name Too Long) uno degli elementi del pathname
 *           supera la lunghezza consentita (MAX_LEN_NAME).
 *         - ENSFD (Error Not Such File or Directory) se un elemento del
 *           pah non siste o non e' una directory.
 *         - ENMSD (Error No More Space on Device) se non ci 
 *           sono piu' blocchi disponibili e quindi ci troviamo
 *           in una condizione di Filesystem Full.
 *         - ERFCD (Error Reading Fat Control Data) se si verifica 
 *           un errore leggendo le strutture di controllo del
 *           filesystem Fat.
 *         - EWFCD (Error Writing Fat Control Data) se si verifica 
 *           un errore durante la scrittura delle strutture di 
 *           controllo del filesystem Fat.
 *         - 0 (zero) in caso di successo
 *
 */
int fat_open (FILE *fs, struct fat_ctrl *f_ctrl, char *path);
