/**
 * \file 
 * \brief Lettura da file regolare
 * \author lcs07
 */
#include "fat.h"
/**
 * Questa funzione ha il compito di leggere una sequenza di byte di un file
 * memorizzato all'interno di un filesystem SFAT. La sequenza viene
 * specificata tramite due parametri:
 *
 * - La posizione \e P del primo byte che si vuole leggere. Il primo byte del 
 *   file ha posizione 0 (zero), il secondo posizione 1 e cosi' via.
 * - Il numero \e NB di byte che si vogliono leggere a 
 *   partire dalla posizione \e P.
 *
 * La funzione deve:
 * - Estrarre le informazioni relative al file \e F che deve essere 
 *   acceduto in lettura.
 * - Detrminare il blocco \e B che contiene il primo byte del
 *   file che deve essere letto.
 * - Determinare l'offset all'interno del blocco \e B da cui iniziare 
 *   la lettura dei dati.
 * - Seguire la catena dei blocchi utilizzati per memorizzare il
 *   file \e F sino a che sono stati acceduti \e NB bytes o
 *   si e' raggiunta la fine del file.
 *
 * @param fs il FILE pointer che consente di acceddre al
 *           file dove il filesystem e' memorizzato.
 * @param f_ctrl puntatore alla struttura che mantiene tutte 
 *               le informazioni di controllo del filesystem.
 * @param path la stringa che contiene il path assoluto del
 *             file che deve essere letto.
 * @param start la posizione del byte da cui cominciare la lettura.
 * @param data_len il numero di byte da leggere a partire dal byte
 *                 in posizone \c start.
 * @param data il buffer in cui copiare i dati letti dal file.
 *             Il buffer deve essere allocato opportunamente.
 * @returns
 *         - EBDP (Error Bad Directory Path) se il path specificato
 *           non e' assoluto, ossia non inizia con il carattere '/'
 *          - In caso di successo la funzione torna un numero non
 *           negativo che indica il numero di bytes letti. Tale 
 *           numero puo'risultare inferiore a \c data_len nel
 *           caso in cui si incontri la fine del file prima di
 *           leggere \c data_len bytes.
 * 
 */
int fat_read(FILE *fs, struct fat_ctrl *f_ctrl, char *path, int start, 
	     int data_len, char *data);
