/**
 * \file
 * \brief Scrittura su file regolare
 * \author lcs07
*/

#include "fat.h"
/**
 * Questa funzione ha il compito di scrivere una sequenza di byte all'interno
 * di un file memorizzato in un filesystem SFAT. Osserviamo che:
 *
 * - Il file su cui si vuole effettuare la scrittura deve essere 
 *   gia' stato creato all'interno del filesystem SFAT.
 * - I dati che debbono essere scritti sono visti da questa funzione 
 *   come una sequenza di byte.
 * - I dati vengono sempre scritti alla fine del file.
 *
 * Questa funzione deve realizzare le seguenti operazioni:
 * - Controllare che il file esista.
 * - Determinare il blocco e l'offset all'interno del blocco
 *   in cui effettuare la scrittura dei nuovi dati.
 * - Determinare se sia necessario allocare uno o piu' 
 *   blocchi in cui memorizzare i nuovi dati.
 * - Scrivere i nuovi dati eventualmente distribuendoli tra
 *   i vari blocchi allocati al passo precedente.
 * - Aggiornare in modo consistente le varie sttruture dati
 *   come ad esempio la lunghezza del file e la File Allocation
 *   table.
 *
 * @param fs il FILE pointer che consente di acceddre al
 *           file dove il filesystem e' memorizzato.
 * @param f_ctrl puntatore alla struttura che mantiene tutte 
 *               le informazioni di controllo del filesystem.
 * @param path la stringa che contiene il path assoluto del
 *              file su cui effettuare la scrittura.
 * @param data il buffer contenete i nuovi dati da scrivere
 *             all'interno del file.
 * @param data_len il numero di bytes contenuti nel buffer \c data 
 *                 che debbono essere scritti nel file.
 * @returns
 *         - EBDP (Error Bad Directory Path) se il path specificato
 *           non e' assoluto, ossia non inizia con il carattere '/'
 *         - ENTL (Error Name Too Long) uno degli elementi del pathname
 *           supera la lunghezza consentita (MAX_LEN_NAME).
 *         - ENSFD (Error Not Such File or Directory) se un elemento del
 *           pah non siste o non e' una directory.
 *         - 0 se l'operazione termina con successo.
 */
int fat_write(FILE *fs, struct fat_ctrl *f_ctrl, char *path, char* data, int data_len);
